Clazz.declarePackage("JU");
Clazz.load(["java.io.IOException"], "JU.ZStreamException", null, function(){
var c$ = Clazz.declareType(JU, "ZStreamException", java.io.IOException);
});
;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
